"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.allResolvers = void 0;

/**
 * Resolver implementation to resolve and array of resolvers into an array of results.
 *
 * @param {[Function]} resolvers Array of resolvers.
 * @return {Function} resolver.
 */
var allResolvers = function allResolvers(resolvers) {
  return function () {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return Promise.all(resolvers.map(function (resolver) {
      return resolver.apply(void 0, args);
    }));
  };
};

exports.allResolvers = allResolvers;